@@ -17,8 +17,7 @@ use Mail::POP3::Security::Connection;
 
 # UIDL is the Message-ID
 
-use vars qw($VERSION);
-$VERSION = "3.08";
+our $VERSION = "3.09";
 
 sub read_config {
     my ($class, $config_text) = @_;
@@ -68,30 +67,37 @@ Mail::POP3 -- a module implementing a full POP3 server
 
 =head1 SYNOPSIS
 
-    use Mail::POP3;
-    my $config_text = Mail::POP3->from_file($config_file);
-    my $config = Mail::POP3->read_config($config_text);
-    Mail::POP3->make_sane($config);
-    while (my $sock = $server_sock->accept) {
-        my $server = Mail::POP3::Server->new(
-            $config,
-        );
-        $server->start(
-            $sock,
-            $sock,
-            $sock->peerhost,
-        );
-    }
+  use Mail::POP3;
+  my $config_text = Mail::POP3->from_file($config_file);
+  my $config = Mail::POP3->read_config($config_text);
+  Mail::POP3->make_sane($config);
+  while (my $sock = $server_sock->accept) {
+    my $server = Mail::POP3::Server->new(
+      $config,
+    );
+    $server->start(
+      $sock,
+      $sock,
+      $sock->peerhost,
+    );
+  }
 
 =head1 DESCRIPTION
 
 C<Mail::POP3> and its associated classes work together as follows:
 
-L<Mail::POP3::Daemon> does the socket-accepting.
-L<Mail::POP3::Server> does (most of) the network POP3 stuff.
-L<Mail::POP3::Security::User> and L<Mail::POP3::Security::Connection>
+=over
+
+=item L<Mail::POP3::Daemon> does the socket-accepting.
+
+=item L<Mail::POP3::Server> does (most of) the network POP3 stuff.
+
+=item L<Mail::POP3::Security::User> and L<Mail::POP3::Security::Connection>
 do the checks on users and connections.
-C<Mail::POP3::Folder::*> classes handles the mail folders.
+
+=item C<Mail::POP3::Folder::*> classes handles the mail folders.
+
+=back
 
 This last characteristic means that diverse sources of information
 can be served up as though they are a POP3 mailbox by implementing
@@ -104,18 +110,89 @@ as C<+>), location radius in miles, location (e.g. Berlin). E.g. the
 username C<perl:5:Berlin> would search for jobs relating to Perl within
 5 miles of Berlin.
 
-=head2 COPYRIGHT
+=head1 OVERVIEW
+
+L<Mail::POP3> is a working POP3 server module, with a working C<mpopd>
+that can either work as a standalone, be called from C<inetd>, or be
+used in non-forking mode for use on Windows platforms that do not do
+forking correctly.
+
+=head1 SCRIPTS
+
+=over
+
+=item mpopd
+
+The core. Read this to see how to use modules.
+
+=item mpopdctl
+
+Gives command-line control of a running mpopd.
+
+=item mpopdstats
+
+Gives command-line statistics from mpopd.
+
+=item installscript
+
+Helps install mpopd and create configuration.
+
+=item update-conf
+
+Helps you upgrade an older config (the file format changed).
+
+=back
+
+=head1 DESIGN
+
+=over
+
+=item Mail::POP3::Daemon does the socket-accepting.
+
+=item Mail::POP3::Server does (most of) the network POP3 stuff.
+
+=item Mail::POP3::Security::{User,Connection} do the checks on users and connections.
+
+=item Mail::POP3::Folder::* classes handles the mail folders.
+
+=back
+
+This last characteristic means that diverse sources of information can
+be served up as though they are a POP3 mailbox by implementing a M::P::F
+subclass. An example is provided in M::P::F::webscrape.
+
+=head1 FUTURE
+
+This module will become a L<Net::Server> subclass, such that the Folder
+functionality will be folded back into the server, in a class called
+(probably) C<Net::Server::POP3::webscrape> (etc).
+
+=head1 METHODS
+
+All class methods.
+
+=head2 from_file
+
+Given a file, returns contentx.
+
+=head2 make_sane
+
+Mutates given config hashref to have good, default values.
+
+=head2 read_config
+
+Given config text, evals it then version-checks.
+
+=head1 COPYRIGHT
 
 Copyright (c) Mark Tiramani 1998-2001 - up to version 2.21.
 Copyright (c) Ed J 2001+ - version 3+.
 All rights reserved. This program is free software; you can
 redistribute it and/or modify it under the same terms as Perl itself.
 
-=head2 DISCLAIMER
+=head1 DISCLAIMER
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 See the Artistic License for more details.
-
-=cut
